==> physx-jni-0.3.2-sources.jar: physx/geomutils/PxConvexMesh.java <==
package physx.geomutils;

import physx.common.PxBase;
import physx.common.PxBounds3;
import physx.common.PxU8Ptr;
import physx.common.PxVec3;

public class PxConvexMesh extends PxBase {

    protected PxConvexMesh() { }

    public static PxConvexMesh wrapPointer(long address) {
        return new PxConvexMesh(address);
    }
    
    protected PxConvexMesh(long address) {
        super(address);
    }

    // Functions

    /**
     * @return unsigned long
     */
    public int getNbVertices() {
        return _getNbVertices(address);
    }
    private static native int _getNbVertices(long address);

    /**
     * @return {@link PxVec3} [Const]
     */
    public PxVec3 getVertices() {
        return PxVec3.wrapPointer(_getVertices(address));
    }
    private static native long _getVertices(long address);

    /**
     * @return {@link PxU8Ptr} [Value]
     */
    public PxU8Ptr getIndexBuffer() {
        return PxU8Ptr.wrapPointer(_getIndexBuffer(address));
    }
    private static native long _getIndexBuffer(long address);

    /**
     * @return unsigned long
     */
    public int getNbPolygons() {
        return _getNbPolygons(address);
    }
    private static native int _getNbPolygons(long address);

    /**
     * @param index unsigned long
     * @param data  {@link PxHullPolygon} [Ref]
     * @return boolean
     */
    public boolean getPolygonData(int index, PxHullPolygon data) {
        return _getPolygonData(address, index, data.getAddress());
    }
    private static native boolean _getPolygonData(long address, int index, long data);

    /**
     * @return unsigned long
     */
    public int getReferenceCount() {
        return _getReferenceCount(address);
    }
    private static native int _getReferenceCount(long address);

    public void acquireReference() {
        _acquireReference(address);
    }
    private static native void _acquireReference(long address);

    /**
     * @return {@link PxBounds3} [Value]
     */
    public PxBounds3 getLocalBounds() {
        return PxBounds3.wrapPointer(_getLocalBounds(address));
    }
    private static native long _getLocalBounds(long address);

    /**
     * @return boolean
     */
    public boolean isGpuCompatible() {
        return _isGpuCompatible(address);
    }
    private static native boolean _isGpuCompatible(long address);

}

==> physx-jni-0.4.0-sources.jar: physx/geomutils/PxConvexMesh.java <==
package physx.geomutils;

import physx.common.PxBase;
import physx.common.PxBounds3;
import physx.common.PxVec3;
import physx.support.PxU8Ptr;

public class PxConvexMesh extends PxBase {

    protected PxConvexMesh() { }

    public static PxConvexMesh wrapPointer(long address) {
        return new PxConvexMesh(address);
    }
    
    protected PxConvexMesh(long address) {
        super(address);
    }

    // Functions

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbVertices() {
        return _getNbVertices(address);
    }
    private static native int _getNbVertices(long address);

    /**
     * @return WebIDL type: {@link PxVec3} [Const]
     */
    public PxVec3 getVertices() {
        return PxVec3.wrapPointer(_getVertices(address));
    }
    private static native long _getVertices(long address);

    /**
     * @return WebIDL type: {@link PxU8Ptr} [Value]
     */
    public PxU8Ptr getIndexBuffer() {
        return PxU8Ptr.wrapPointer(_getIndexBuffer(address));
    }
    private static native long _getIndexBuffer(long address);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getNbPolygons() {
        return _getNbPolygons(address);
    }
    private static native int _getNbPolygons(long address);

    /**
     * @param index WebIDL type: unsigned long
     * @param data  WebIDL type: {@link PxHullPolygon} [Ref]
     * @return WebIDL type: boolean
     */
    public boolean getPolygonData(int index, PxHullPolygon data) {
        return _getPolygonData(address, index, data.getAddress());
    }
    private static native boolean _getPolygonData(long address, int index, long data);

    /**
     * @return WebIDL type: unsigned long
     */
    public int getReferenceCount() {
        return _getReferenceCount(address);
    }
    private static native int _getReferenceCount(long address);

    public void acquireReference() {
        _acquireReference(address);
    }
    private static native void _acquireReference(long address);

    /**
     * @return WebIDL type: {@link PxBounds3} [Value]
     */
    public PxBounds3 getLocalBounds() {
        return PxBounds3.wrapPointer(_getLocalBounds(address));
    }
    private static native long _getLocalBounds(long address);

    /**
     * @return WebIDL type: boolean
     */
    public boolean isGpuCompatible() {
        return _isGpuCompatible(address);
    }
    private static native boolean _isGpuCompatible(long address);

}
